(function() {
  'use strict';

  var globals = typeof global === 'undefined' ? self : global;
  if (typeof globals.require === 'function') return;

  var modules = {};
  var cache = {};
  var aliases = {};
  var has = {}.hasOwnProperty;

  var expRe = /^\.\.?(\/|$)/;
  var expand = function(root, name) {
    var results = [], part;
    var parts = (expRe.test(name) ? root + '/' + name : name).split('/');
    for (var i = 0, length = parts.length; i < length; i++) {
      part = parts[i];
      if (part === '..') {
        results.pop();
      } else if (part !== '.' && part !== '') {
        results.push(part);
      }
    }
    return results.join('/');
  };

  var dirname = function(path) {
    return path.split('/').slice(0, -1).join('/');
  };

  var localRequire = function(path) {
    return function expanded(name) {
      var absolute = expand(dirname(path), name);
      return globals.require(absolute, path);
    };
  };

  var initModule = function(name, definition) {
    var hot = hmr && hmr.createHot(name);
    var module = {id: name, exports: {}, hot: hot};
    cache[name] = module;
    definition(module.exports, localRequire(name), module);
    return module.exports;
  };

  var expandAlias = function(name) {
    var val = aliases[name];
    return (val && name !== val) ? expandAlias(val) : name;
  };

  var _resolve = function(name, dep) {
    return expandAlias(expand(dirname(name), dep));
  };

  var require = function(name, loaderPath) {
    if (loaderPath == null) loaderPath = '/';
    var path = expandAlias(name);

    if (has.call(cache, path)) return cache[path].exports;
    if (has.call(modules, path)) return initModule(path, modules[path]);

    throw new Error("Cannot find module '" + name + "' from '" + loaderPath + "'");
  };

  require.alias = function(from, to) {
    aliases[to] = from;
  };

  var extRe = /\.[^.\/]+$/;
  var indexRe = /\/index(\.[^\/]+)?$/;
  var addExtensions = function(bundle) {
    if (extRe.test(bundle)) {
      var alias = bundle.replace(extRe, '');
      if (!has.call(aliases, alias) || aliases[alias].replace(extRe, '') === alias + '/index') {
        aliases[alias] = bundle;
      }
    }

    if (indexRe.test(bundle)) {
      var iAlias = bundle.replace(indexRe, '');
      if (!has.call(aliases, iAlias)) {
        aliases[iAlias] = bundle;
      }
    }
  };

  require.register = require.define = function(bundle, fn) {
    if (bundle && typeof bundle === 'object') {
      for (var key in bundle) {
        if (has.call(bundle, key)) {
          require.register(key, bundle[key]);
        }
      }
    } else {
      modules[bundle] = fn;
      delete cache[bundle];
      addExtensions(bundle);
    }
  };

  require.list = function() {
    var list = [];
    for (var item in modules) {
      if (has.call(modules, item)) {
        list.push(item);
      }
    }
    return list;
  };

  var hmr = globals._hmr && new globals._hmr(_resolve, require, modules, cache);
  require._cache = cache;
  require.hmr = hmr && hmr.wrap;
  require.brunch = true;
  globals.require = require;
})();

(function() {
var global = typeof window === 'undefined' ? this : window;
var __makeRelativeRequire = function(require, mappings, pref) {
  var none = {};
  var tryReq = function(name, pref) {
    var val;
    try {
      val = require(pref + '/node_modules/' + name);
      return val;
    } catch (e) {
      if (e.toString().indexOf('Cannot find module') === -1) {
        throw e;
      }

      if (pref.indexOf('node_modules') !== -1) {
        var s = pref.split('/');
        var i = s.lastIndexOf('node_modules');
        var newPref = s.slice(0, i).join('/');
        return tryReq(name, newPref);
      }
    }
    return none;
  };
  return function(name) {
    if (name in mappings) name = mappings[name];
    if (!name) return;
    if (name[0] !== '.' && pref) {
      var val = tryReq(name, pref);
      if (val !== none) return val;
    }
    return require(name);
  }
};
require.register("js/admin-refresh-box-status.js", function(exports, require, module) {
'use strict'
var $

exports.init = function (jQuery) {
  $ = jQuery

  $(document).on('click', '.bpost-refresh-box-status-action', function () {
    var $refresh_button = $('.bpost-refresh-box-status-action')
    $refresh_button.attr('disabled', true)

    var $status_span = $('#bpost-order-meta-status')
    $status_span.html('<i>Refreshing status...</i>')

    var xhr = $.ajax({
      url: window.bpost_order_data.url,
      method: 'GET',
      dataType: 'json'
    })

    xhr.done(function successHandler (result) {
      $status_span.html(result[window.bpost_order_data.order_id])
    })

    xhr.fail(function errorHandler (jqXHR, textStatus, errorThrown) {
      console.error(jqXHR, textStatus, errorThrown)
      $status_span.html('<i>Error during the refreshing of the status</i>')
    })

    xhr.always(function () {
      $refresh_button.attr('disabled', false)
    })
  })
}

});

;require.register("js/after-checkout.js", function(exports, require, module) {
'use strict'
var $,
  $checkout_form,
  shmTriggering

function trigger_update_checkout () {
  $(document.body).trigger('update_checkout')
}

function on_shm_close (data) {
  var init_overlay = tb_click // it's an alias to understand what tb_click does

  init_overlay()

  if (!data.status) {
    console.error('error status from shm callback')
    trigger_update_checkout()
    remove_overlay()
    return
  }

  delete data.status

  var FormFiller = require('js/form-filler')
  var formFiller = new FormFiller($checkout_form)
  formFiller.createOrFillFields(data)
  shmTriggering.add_hidden_item()

  call_classic_checkout_process()
  remove_overlay()
}

function call_classic_checkout_process () {
  $checkout_form.submit()
}

exports.init = function (jQuery) {
  $ = jQuery
  $checkout_form = $('form.checkout')

  var ShmTriggering = require('js/shm-triggering')
  shmTriggering = new ShmTriggering({
    jquery: jQuery,
    $form: $checkout_form,
    on_shm_close: on_shm_close
  })

  shmTriggering.monitor_errors()
}

});

;require.register("js/form-filler.js", function(exports, require, module) {

function FormFiller ($checkout_form) {
  if (undefined === $checkout_form) {
    throw Error('A checkout item must be specified')
  }
  this.$checkout_form = $checkout_form
  this.fragmentStorageHiddenFields = document.createDocumentFragment()
}

FormFiller.prototype.isBpostAdditionalField = function (formIndex) {
  return formIndex.indexOf('bpost') === 0
}

FormFiller.prototype.createOrFillFields = function (data) {
  for (var formIndex in data) {
    if (!data.hasOwnProperty(formIndex)) {
      continue
    }
    if (this.isBpostAdditionalField(formIndex)) {
      this.createHiddenField(formIndex, data[formIndex])
      continue
    }
    try {
      this.fillFieldIfAvailable(formIndex, data[formIndex])
    } catch (e) {
      console.warn(e)
    }
  }
  this.publishHiddenFields()
}

FormFiller.prototype.createHiddenField = function (name, value) {
  var input = document.createElement('input')
  input.setAttribute('type', 'hidden')
  input.setAttribute('name', name)
  input.setAttribute('value', value)
  this.fragmentStorageHiddenFields.appendChild(input)
  return input
}

FormFiller.prototype.retrieveField = function (name) {
  return this.$checkout_form.find('[name=' + name + ']')
}

FormFiller.prototype.isFieldPresent = function (name) {
  return this.retrieveField(name).length === 1
}

FormFiller.prototype.fillFieldIfAvailable = function (name, value) {
  var $fieldFound = this.retrieveField(name)
  if ($fieldFound.length !== 1) {
    throw new Error('Avoid to fill input "' + name + '" (not found or duplicate)')
  }

  if ($fieldFound.is("[type='checkbox']")) {
    $fieldFound.prop('checked', true)
  } else if ($fieldFound.is('select')) {
    $fieldFound.remove()
    this.createHiddenField(name, value)
  } else {
    $fieldFound.val(value)
  }
}

FormFiller.prototype.publishHiddenFields = function () {
  this.$checkout_form.get(0).appendChild(this.fragmentStorageHiddenFields)
}

module.exports = FormFiller

});

;require.register("js/gmap-loader.js", function(exports, require, module) {
function GMapLoader (api_key, address, map_element, signed_in) {
  this.api_key = api_key
  this.address = address
  this.map_element = map_element
  this.signed_in = signed_in
}

GMapLoader.prototype.process_reverse = function () {
  geocoder = new google.maps.Geocoder()
  var that = this
  geocoder.geocode({ 'address': this.address }, this.build_map.bind(that))
}

GMapLoader.prototype.build_options = function (location) {
  return {
    zoom: 17,
    center: location,
    disableDefaultUI: true,
    navigationControl: false
  }
}

GMapLoader.prototype.build_map = function (results, status) {
  if (status !== google.maps.GeocoderStatus.OK) {
    console.error('Non geolocalised address: ' + this.address)
    return
  }

  var location = results[0].geometry.location

  var myOptions = this.build_options(location)

  var map = new google.maps.Map(this.map_element, myOptions)

  new google.maps.Marker({
    position: location,
    map: map
  })
}

GMapLoader.prototype.loadGoogleMaps = function (callback_name) {
  if (!this.api_key) {
    console.warn('No api key provided, google maps wont work')
    return
  }
  var googleMaps = document.createElement('script')
  googleMaps.type = 'text/javascript'
  googleMaps.src = 'https://maps.googleapis.com/maps/api/js?key=' + this.api_key
      + '&signed_in=' + this.signed_in
      + '&callback=' + callback_name
  document.body.appendChild(googleMaps)
}

module.exports = GMapLoader

// document.getElementById('map')

});

;require.register("js/hello-world.js", function(exports, require, module) {
'use strict'

exports.sayHello = function () {
  return 'wello horld'
}

});

;require.register("js/shm-builder.js", function(exports, require, module) {
'use strict'

function add_shipping_data (dto, shipping) {
  dto.customerFirstName = shipping.first_name
  dto.customerLastName = shipping.last_name
  dto.customerStreet = shipping.address
  dto.customerStreetNumber = shipping.street_number
  dto.customerBox = shipping.street_box
  dto.customerCity = shipping.city
  dto.customerPostalCode = shipping.post_code
  dto.customerCountry = shipping.country_code
  dto.customerEmail = shipping.email
  dto.customerPhoneNumber = shipping.phone_number
  dto.customerCompany = shipping.company

  return dto
}

function add_bpost_data (dto, bpost_data) {
  dto.accountId = bpost_data.account_id
  dto.orderReference = bpost_data.order_reference
  dto.checksum = bpost_data.hash
  dto.additionalCustomerReference = bpost_data.additional_customer_ref
  dto.lang = bpost_data.language
  dto.orderTotalPrice = bpost_data.sub_total
  dto.deliveryMethodOverrides = bpost_data.delivery_method_overrides
  dto.orderWeight = bpost_data.sub_weight
  dto.extra = bpost_data.extra

  dto.confirmUrl = bpost_data.callback_url + 'confirm' // check RESULT_SHM_CALLBACK.* constants into shm_callback.php
  dto.errorUrl = bpost_data.callback_url + 'error'
  dto.cancelUrl = bpost_data.callback_url + 'cancel'

  return dto
}

var build_shm_parameters = function (bpost_data, shipping) {
  var shipping_data = add_shipping_data({}, shipping)
  var full_data = add_bpost_data(shipping_data, bpost_data)

  full_data.action = 'START'
  return full_data
}

exports.build_data = function (bpost_data, shipping_address, on_shm_close) {
  if (arguments.length != 3) {
    throw new Error('Please provide at least three params')
  }

  var shm_params = {}

  shm_params.integrationType = 'POPUP'
  shm_params.forceIntegrationType = 'true' // To force the popup display on mobile devices
  shm_params.parameters = build_shm_parameters(bpost_data, shipping_address)
  shm_params.closeCallback = on_shm_close

  return shm_params
}

});

;require.register("js/shm-close.js", function(exports, require, module) {
'use strict'

// Close the SHM and send data to WP
exports.close_shm = function (SHM, shm_data) {
  if (!SHM || !shm_data) {
    return
  }

  SHM.close(shm_data)
}

});

;require.register("js/shm-triggering.js", function(exports, require, module) {
function ShmTriggering (config) {
  if (arguments.length !== 1) {
    throw Error('Please provide one arguments')
  }
  this.$ = config.jquery
  this.$form = config.$form
  this.on_shm_close = config.on_shm_close
}

ShmTriggering.prototype.add_hidden_item = function () {
  var FormFiller = require('js/form-filler')
  var form_filler = new FormFiller(this.$form)
  if (!form_filler.isFieldPresent('bpost_shm_already_called')) {
    form_filler.createHiddenField('bpost_shm_already_called', 1)
    form_filler.publishHiddenFields()
  }
}

ShmTriggering.prototype.remove_error_container = function ($wc_errors) {
  var $error_container = $wc_errors.parent().parent()

  // woocommerce classic path
  if ($error_container.hasClass('woocommerce-error')) {
    $error_container.remove()
    return
  }

  // notio theme hack
  if ($error_container.attr('role') === 'alert') {
    $error_container.remove()
  }
}

ShmTriggering.prototype.checkout_error = function () {
  var $wc_errors = this.$('span#shm_must_be_open')
  if ($wc_errors.length !== 1) {
    return
  }
  this.remove_error_container($wc_errors)

  this.get_bpost_shm_data()
}

ShmTriggering.prototype.monitor_errors = function () {
  var that = this
  this.$(document.body).on('checkout_error', function () {
    that.checkout_error()
  })
}

ShmTriggering.prototype.launch_bpost_shm = function (response) {
  var shm_builder = require('js/shm-builder')
  var that = this
  SHM.open(shm_builder.build_data(response.bpost_data, response.shipping_address, function (data) {
    that.on_shm_close(data)
  }))
}

ShmTriggering.prototype.get_bpost_shm_data = function () {
  console.log('get_bpost_shm_data')

  var $formContent = this.$.grep(this.$form.find('input, select'), filter_form_input_select)
  var that = this
  this.$.ajax({
    url: window.bpost_after_checkout.url,
    method: 'POST',
    data: $formContent,
    success: function (response) { that.launch_bpost_shm(response) },
    dataType: 'json'
  })
}

function filter_form_input_select (form_item) {
  if (!form_item.name) {
    return false
  }

  if (form_item.name.indexOf('_name') !== -1) {
    return true
  }

  if (form_item.name.indexOf('_company') !== -1) {
    return true
  }

  if (form_item.name.indexOf('_email') !== -1) {
    return true
  }

  if (form_item.name.indexOf('_phone') !== -1) {
    return true
  }

  if (form_item.name.indexOf('payment_method') !== -1 && jQuery(form_item).is(':checked')) {
    return true
  }

  return form_item.name.indexOf('different_address') !== -1 && jQuery(form_item).is(':checked')
}

module.exports = ShmTriggering

});

;require.register("___globals___", function(exports, require, module) {
  
});})();require('___globals___');

